@@ -11,11 +11,11 @@ JIRA::Client - An extended interface to JIRA's SOAP API.
 
 =head1 VERSION
 
-Version 0.26
+Version 0.28
 
 =cut
 
-our $VERSION = '0.26';
+our $VERSION = '0.28';
 
 =head1 SYNOPSIS
 
@@ -98,19 +98,21 @@ distinguish them and we can avoid future name clashes.
 
 =over 4
 
-=item B<new> JIRAURL, USER, PASSWD
+=item B<new> JIRAURL, USER, PASSWD [, <SOAP::Lite arguments>]
 
-The JIRA::Client constructor needs three arguments. JIRAURL is JIRA's
-base URL from which will be constructed it's WSDL descriptor as
+The JIRA::Client constructor requires three arguments. JIRAURL is
+JIRA's base URL from which will be constructed it's WSDL descriptor as
 C<$JIRAURL/rpc/soap/jirasoapservice-v2?wsdl>. USER and PASSWD are the
-credentials that will be used to authenticate into JIRA.
+credentials that will be used to authenticate into JIRA. Any other
+arguments will be passed to the L<SOAP::Lite> object that will be
+created to talk to JIRA.
 
 =cut
 
 sub new {
-    my ($class, $base_url, $user, $pass) = @_;
+    my ($class, $base_url, $user, $pass, @args) = @_;
 
-    my $soap = SOAP::Lite->proxy("$base_url/rpc/soap/jirasoapservice-v2?wsdl");
+    my $soap = SOAP::Lite->proxy("$base_url/rpc/soap/jirasoapservice-v2?wsdl", @args);
 
     # Make all scalars be encoded as strings by default.
     %{$soap->typelookup()} = (default => [0, sub {1}, 'as_string']);
@@ -1094,21 +1096,27 @@ package JIRA::Client;
 # zero-based, after the authentication token.
 
 my %typeof = (
+    addActorsToProjectRole                   => {1 => \&_cast_remote_project_role},
     addAttachmentsToIssue              	     => \&_cast_attachments,
     addBase64EncodedAttachmentsToIssue 	     => \&_cast_base64encodedattachments,
     addComment                         	     => {0 => \&_cast_issue_key, 1 => \&_cast_remote_comment},
+    addDefaultActorsToProjectRole            => {1 => \&_cast_remote_project_role},
     addWorklogAndAutoAdjustRemainingEstimate => {0 => \&_cast_issue_key},
     addWorklogAndRetainRemainingEstimate     => {0 => \&_cast_issue_key},
     addWorklogWithNewRemainingEstimate       => {0 => \&_cast_issue_key},
     archiveVersion                     	     => {2 => 'boolean'},
     createIssueWithSecurityLevel       	     => {1 => 'long'},
+    createProjectRole                        => {0 => \&_cast_remote_project_role},
     deleteIssue                 	     => {0 => \&_cast_issue_key},
     deleteProjectAvatar                	     => {0 => 'long'},
-    deleteProjectRole                  	     => {1 => 'boolean'},
+    deleteProjectRole                  	     => {0 => \&_cast_remote_project_role, 1 => 'boolean'},
+    getAssociatedNotificationSchemes         => {0 => \&_cast_remote_project_role},
+    getAssociatedPermissionSchemes           => {0 => \&_cast_remote_project_role},
     getAttachmentsFromIssue           	     => {0 => \&_cast_issue_key},
     getAvailableActions           	     => {0 => \&_cast_issue_key},
     getComment                         	     => {0 => 'long'},
     getComments                        	     => {0 => \&_cast_issue_key},
+    getDefaultRoleActors                     => {0 => \&_cast_remote_project_role},
     getFieldsForAction                 	     => {0 => \&_cast_issue_key},
     getFieldsForEdit                 	     => {0 => \&_cast_issue_key},
     getIssue	                 	     => {0 => \&_cast_issue_key},
@@ -1121,6 +1129,7 @@ my %typeof = (
     getProjectAvatars                  	     => {1 => 'boolean'},
     getProjectById                     	     => {0 => 'long'},
     getProjectRole                     	     => {0 => 'long'},
+    getProjectRoleActors               	     => {0 => \&_cast_remote_project_role},
     getProjectWithSchemesById          	     => {0 => 'long'},
     getResolutionDateById              	     => {0 => 'long'},
     getResolutionDateByKey             	     => {0 => \&_cast_issue_key},
@@ -1128,8 +1137,11 @@ my %typeof = (
     getWorklogs		             	     => {0 => \&_cast_issue_key},
     hasPermissionToCreateWorklog       	     => {0 => \&_cast_issue_key},
     progressWorkflowAction             	     => {0 => \&_cast_issue_key, 2 => \&_cast_remote_field_values},
+    removeActorsFromProjectRole              => {1 => \&_cast_remote_project_role},
+    removeDefaultActorsFromProjectRole       => {1 => \&_cast_remote_project_role},
     setProjectAvatar                   	     => {1 => 'long'},
     updateIssue                        	     => {0 => \&_cast_issue_key, 1 => \&_cast_remote_field_values},
+    updateProjectRole                        => {0 => \&_cast_remote_project_role},
 );
 
 sub _cast_issue_key {
@@ -1159,6 +1171,14 @@ sub _cast_remote_field_values {
     return $arg;
 }
 
+sub _cast_remote_project_role {
+    my ($self, $arg) = @_;
+    if (ref $arg && ref $arg eq 'RemoteProjectRole' && exists $arg->{id} && ! ref $arg->{id}) {
+	$arg->{id} = SOAP::Data->type(long => $arg->{id});
+    }
+    return $arg;
+}
+
 sub _cast_attachments {
     my ($self, $method, $args) = @_;
     # The addAttachmentsToIssue method is deprecated and requires too
@@ -1277,7 +1297,7 @@ L<http://search.cpan.org/dist/JIRA-Client>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 CPqD, all rights reserved.
+Copyright 2009-2011 CPqD, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
